@@ -1,35 +1,20 @@
 import os
+import click
 from requests import get
-from jovian.utils.constants import API_URL, ISSUES_MSG
+
 from jovian._version import __version__
-from jovian.utils.credentials import get_guest_key, read_api_key_opt
+from jovian.utils.constants import ISSUES_MSG
+
+from jovian.utils.credentials import get_guest_key, read_api_key_opt, read_api_url, read_org_id
 from jovian.utils.logger import log
-from jovian.utils.rcfile import set_notebook_slug, get_rcdata, rcfile_exists
+from jovian.utils.rcfile import get_rcdata, rcfile_exists, set_notebook_slug
+from jovian.utils.request import pretty
+from jovian.utils.misc import urljoin
 
 
 def _u(path):
     """Make a URL from the path"""
-    return API_URL + path
-
-
-def _msg(res):
-    try:
-        data = res.json()
-        if 'errors' in data and len(data['errors'] > 0):
-            return data['errors'][0]['message']
-        if 'message' in data:
-            return data['message']
-        if 'msg' in data:
-            return data['msg']
-    except:
-        if res.text:
-            return res.text
-        return 'Something went wrong'
-
-
-def _pretty(res):
-    """Make a human readable output from an HTML response"""
-    return '(HTTP ' + str(res.status_code) + ') ' + _msg(res)
+    return urljoin(read_api_url(), path)
 
 
 def _h(fresh):
@@ -39,7 +24,8 @@ def _h(fresh):
     headers = {"x-jovian-source": "library",
                "x-jovian-library-version": __version__,
                "x-jovian-command": "clone" if fresh else "pull",
-               "x-jovian-guest": get_guest_key()}
+               "x-jovian-guest": get_guest_key(),
+               "x-jovian-org": read_org_id()}
 
     if api_key is not None:
         headers["Authorization"] = "Bearer " + api_key
@@ -56,34 +42,40 @@ def _v(version):
 
 def get_gist(slug, version, fresh):
     """Download a gist"""
-    url = _u('/gist/' + slug + _v(version))
+    if '/' in slug:
+        parts = slug.split('/')
+        username, title = parts[0], parts[1]
+        url = _u('user/' + username + '/gist/' + title + _v(version))
+    else:
+        url = _u('gist/' + slug + _v(version))
     res = get(url, headers=_h(fresh))
     if res.status_code == 200:
         return res.json()['data']
-    raise Exception('Failed to retrieve Gist: ' + _pretty(res))
+    raise Exception('Failed to retrieve Gist: ' + pretty(res))
 
 
 def post_clone_msg(title):
-    return """Cloned successfully to '{}'. 
 
-Next steps:
-$ cd {}   # Enter the directory
-$ jovian install     # Install dependencies
-$ conda activate <env_name> # Activate environment
-$ jupyter notebook   # Start Jupyter
+    log("Cloned successfully to '{}'".format(title), color='green')
+    log(click.style('\nNext steps:', fg='yellow', underline=True) +
+        click.style("""
+  $ cd {}                     
+  $ jovian install            
+  $ conda activate <env_name> 
+  $ jupyter notebook
+""".format(title), bold=True), pre=False)
 
+    log("""
 Replace <env_name> with the name of your environment (without the '<' & '>')
-Jovian uses Anaconda ( https://conda.io/ ) under the hood, 
-so please make sure you have it installed and added to path. 
+Jovian uses Anaconda ( https://conda.io/ ) under the hood,
+so please make sure you have it installed and added to path.
 * If you face issues with `jovian install`, try `conda env update`.
-* If you face issues with `conda activate`, try `source activate <env_name>` 
+* If you face issues with `conda activate`, try `source activate <env_name>`
   or `activate <env_name>` to activate the virtual environment.
-
-{}
-""".format(title, title, ISSUES_MSG)
+""", pre=False)
 
 
-def clone(slug, version=None, fresh=True):
+def clone(slug, version=None, fresh=True, include_outputs=True):
     """Download the files for a gist"""
     # Print issues link
     log(ISSUES_MSG)
@@ -108,8 +100,9 @@ def clone(slug, version=None, fresh=True):
     # Download the files
     log('Downloading files..')
     for f in gist['files']:
-        with open(f['filename'], 'wb') as fp:
-            fp.write(get(f['rawUrl']).content)
+        if not f['artifact'] or include_outputs:
+            with open(f['filename'], 'wb') as fp:
+                fp.write(get(f['rawUrl']).content)
 
         # Create .jovianrc for a fresh clone
         if fresh and f['filename'].endswith('.ipynb'):
@@ -117,7 +110,7 @@ def clone(slug, version=None, fresh=True):
 
     # Print success message and instructions
     if fresh:
-        log(post_clone_msg(title))
+        post_clone_msg(title)
     else:
         log('Files dowloaded successfully in current directory')
 
